%global gitver      2.30.1
%global cachedir    %{_localstatedir}/cache/%{name}
%global filterdir   %{_libexecdir}/%{name}/filters
%global scriptdir   %{_localstatedir}/www/cgi-bin
%global cgitdata    %{_datadir}/%{name}

%global cgitmake \
%make_build \\\
     DESTDIR=%{buildroot} \\\
     CACHE_ROOT=%{cachedir} \\\
     CGIT_SCRIPT_PATH=%{scriptdir} \\\
     CGIT_SCRIPT_NAME=cgit \\\
     CGIT_DATA_PATH=%{cgitdata} \\\
     docdir=%{docdir} \\\
     mandir=%{_mandir} \\\
     filterdir=%{filterdir}

Name:           cgit
Version:        1.2.3
Release:        %mkrel 3
Summary:        A fast web interface for git
Group:          System/Servers
License:        GPLv2
URL:            https://git.zx2c4.com/cgit/
Source0:        https://git.zx2c4.com/cgit/snapshot/%{name}-%{version}.tar.xz
Source1:        https://mirrors.edge.kernel.org/pub/software/scm/git/git-%{gitver}.tar.xz
Source2:        cgitrc
Source3:        cgit.httpd
# upstream master
Patch001:	0001-git-update-to-v2.26.0.patch
Patch002:	0002-git-update-to-v2.27.0.patch
Patch003:	0003-git-update-to-v2.28.0.patch
Patch004:	0004-git-update-to-v2.29.0.patch
Patch005:	0005-global-replace-references-to-sha1-with-oid.patch
Patch006:	0006-global-replace-hard-coded-hash-length.patch
Patch007:	0007-tests-do-not-copy-snapshots-to-tmp.patch
Patch008:	0008-tests-try-with-commit-graph.patch
Patch009:	0009-git-update-to-v2.29.1.patch
Patch010:	0010-git-update-to-v2.29.2.patch
Patch011:	0011-git-update-to-v2.30.0.patch
Patch012:	0012-md2html-use-sane_lists-extension.patch
Patch013:	0013-tests-t0107-support-older-and-or-non-GNU-tar.patch
Patch014:	0014-git-update-to-v2.30.1.patch

# highlight change
Patch500:	0500-cgit-0.9.1-highlightv3.patch
# (cg) Formatting patch from http://colin.guthr.ie/git/misc/cgit/log/?h=tweaks
Patch501:	0501-ui-repolist-Add-a-very-simple-pretty-print-option-fo.patch

BuildRequires:  asciidoc
BuildRequires:  docbook-style-xsl
BuildRequires:  xsltproc
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(openssl)
Requires:       webserver
Requires:       highlight

%description
Cgit is a fast web interface for git.  It uses caching to increase performance.

%prep
%setup -q -a 1
%autopatch -p1

# setup the git dir
rm -rf git
mv git-%{gitver} git
sed -i 's/^\(CFLAGS = \).*/\1%{optflags}/' git/Makefile
sed -i "s/GIT_VER = 2.30.1/GIT_VER = %{gitver}/" Makefile


%build
%cgitmake
# Something in the a2x chain doesn't like running in parallel. :/
%cgitmake -j 1 doc-man doc-html


%install
%cgitmake install install-man

install -d -m0755 %{buildroot}%{_sysconfdir}/httpd/conf/webapps.d
install -p -m0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/cgitrc
install -p -m0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/httpd/conf/webapps.d/%{name}.conf
install -d -m0755 %{buildroot}%{cachedir}


%files
%doc COPYING README* *.html
%config(noreplace) %{_sysconfdir}/cgitrc
%config(noreplace) %{_sysconfdir}/httpd/conf/webapps.d/%{name}.conf
%dir %attr(-,apache,root) %{cachedir}
%{cgitdata}
%{filterdir}
%{scriptdir}/*
%{_mandir}/man*/*


%changelog
* Wed Mar 23 2022 umeabot <umeabot> 1.2.3-3.mga9
+ Revision: 1821877
- Mageia 9 Mass Rebuild

* Wed Feb 10 2021 tmb <tmb> 1.2.3-2.mga8
+ Revision: 1675124
- update git to 2.30.1

* Thu Dec 31 2020 tmb <tmb> 1.2.3-1.mga8
+ Revision: 1666668
- add post 1.2.3 fixes from upstream to support git 2.30
+ kekepower <kekepower>
- Update to version 1.2.3

* Sat Feb 15 2020 umeabot <umeabot> 1.2.1-5.mga8
+ Revision: 1526493
- Mageia 8 Mass Rebuild

* Mon May 20 2019 tmb <tmb> 1.2.1-4.mga7
+ Revision: 1398721
- ui-shared: restrict to 15 levels (mga#24843)

* Sat Mar 16 2019 tmb <tmb> 1.2.1-3.mga7
+ Revision: 1378129
- add uppstream fixes to support git 2.21

* Sat Sep 22 2018 umeabot <umeabot> 1.2.1-2.mga7
+ Revision: 1296104
- Mageia 7 Mass Rebuild

* Sat Aug 25 2018 tmb <tmb> 1.2.1-1.mga7
+ Revision: 1254356
- rebase P500, P501
- update to 1.2.1

* Thu Aug 23 2018 tmb <tmb> 0.12-5.mga7
+ Revision: 1253612
- fix CVE-2018-14912 (mga#23398)

* Sat Sep 09 2017 cjw <cjw> 0.12-4.mga7
+ Revision: 1152172
- rebuild for openssl 1.1

* Fri Mar 18 2016 luigiwalser <luigiwalser> 0.12-3.mga6
+ Revision: 992886
- update git again to 2.7.4

* Wed Mar 16 2016 colin <colin> 0.12-2.mga6
+ Revision: 992008
- Build against git 2.7.3

* Fri Jan 22 2016 colin <colin> 0.12-1.mga6
+ Revision: 926558
- New version: 0.12 (git 2.7.0) mga#17495

* Mon Aug 17 2015 colin <colin> 0.11.2-1.mga6
+ Revision: 865319
- New version: 0.11.2 (using git 2.5.0)

* Wed Oct 15 2014 umeabot <umeabot> 0.10.2-4.mga5
+ Revision: 741968
- Second Mageia 5 Mass Rebuild

* Fri Sep 26 2014 tv <tv> 0.10.2-3.mga5
+ Revision: 725005
- rebuild for bogus file deps

* Tue Sep 16 2014 umeabot <umeabot> 0.10.2-2.mga5
+ Revision: 678356
- Mageia 5 Mass Rebuild

* Sat Aug 30 2014 colin <colin> 0.10.2-1.mga5
+ Revision: 669565
- New version: 0.10.2

* Sun Apr 06 2014 colin <colin> 0.10.1-1.mga5
+ Revision: 612474
- Update to 0.10.1

* Sat Oct 19 2013 umeabot <umeabot> 0.9.2-3.mga4
+ Revision: 527563
- Mageia 4 Mass Rebuild

* Sun Jun 09 2013 colin <colin> 0.9.2-2.mga4
+ Revision: 441242
- Fix syntax highlighting script name
- Apply patches maually to avoid back files being included in package

* Sun Jun 09 2013 colin <colin> 0.9.2-1.mga4
+ Revision: 441157
- Add missing BR
- Fix group
- Add formatting patch
- Add some buildrequires and switch to pkgconfig BR where possible.
- Import Fedora package (with tweaks for Mageia)


* Mon May 27 2013 Todd Zullinger <tmz@pobox.com> - 0.9.2-1
- Update to 0.9.2, fixes CVE-2013-2117

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Nov 21 2012 Kevin Fenzi <kevin@scrye.com> 0.9.1-3
- Fixed ldflags. Fixes bug 878611

* Sat Nov 17 2012 Kevin Fenzi <kevin@scrye.com> 0.9.1-2
- Add patch to use correct version of highlight for all branches except epel5

* Thu Nov 15 2012 Kevin Fenzi <kevin@scrye.com> 0.9.1-1
- Update to 0.9.1
- Fixes bug #870714 - CVE-2012-4548
- Fixes bug #820733 - CVE-2012-4465

* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.0.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Jan 12 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.0.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Fri Jul 22 2011 Todd Zullinger <tmz@pobox.com> - 0.9.0.2-2
- Fix potential XSS vulnerability in rename hint

* Thu Jul 21 2011 Todd Zullinger <tmz@pobox.com> - 0.9.0.2-1
- Update to 0.9.0.2

* Sun Mar 06 2011 Todd Zullinger <tmz@pobox.com> - 0.9-1
- Update to 0.9
- Fixes: CVE-2011-1027
  http://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2011-1027
- Generate and install man page and html docs
- Use libcurl-devel on RHEL >= 6
- Include example filter scripts
- Update example cgitrc

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.2.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Sep 27 2010 Todd Zullinger <tmz@pobox.com> - 0.8.2.1-4
- Appy upstream git patch for CVE-2010-2542 (#618108)

* Fri Aug 21 2009 Tomas Mraz <tmraz@redhat.com> - 0.8.2.1-3
- rebuilt with new openssl

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.2.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Sun Mar 15 2009 Todd Zullinger <tmz@pobox.com> - 0.8.2.1-1
- Update to 0.8.2.1

* Mon Feb 23 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sun Feb 01 2009 Todd Zullinger <tmz@pobox.com> - 0.8.2-1
- Update to 0.8.2
- Drop upstreamed Makefile patch

* Sun Jan 18 2009 Todd Zullinger <tmz@pobox.com> - 0.8.1-2
- Rebuild with new openssl

* Mon Jan 12 2009 Todd Zullinger <tmz@pobox.com> - 0.8.1-1
- Initial package
